@@ -1,16 +1,23 @@
-use crate::file::error::{GitConfigError, GitConfigFromEnvError};
-use crate::file::section::{MutableSection, SectionBody};
-use crate::file::value::{EntryData, MutableMultiValue, MutableValue};
-use crate::file::{Index, Size};
-use crate::parser::{
-    parse_from_bytes, parse_from_path, parse_from_str, Error, Event, Key, ParsedSectionHeader, Parser, ParserOrIoError,
-    SectionHeaderName,
+use std::{
+    borrow::Cow,
+    collections::{HashMap, VecDeque},
+    convert::TryFrom,
+    fmt::Display,
+    path::Path,
+};
+
+use crate::{
+    file::{
+        error::{GitConfigError, GitConfigFromEnvError},
+        section::{MutableSection, SectionBody},
+        value::{EntryData, MutableMultiValue, MutableValue},
+        Index, Size,
+    },
+    parser::{
+        parse_from_bytes, parse_from_path, parse_from_str, Error, Event, Key, ParsedSectionHeader, Parser,
+        ParserOrIoError, SectionHeaderName,
+    },
 };
-use std::borrow::Cow;
-use std::collections::{HashMap, VecDeque};
-use std::convert::TryFrom;
-use std::fmt::Display;
-use std::path::Path;
 
 /// The section ID is a monotonically increasing ID used to refer to sections.
 /// This value does not imply any ordering between sections, as new sections
@@ -31,13 +38,19 @@ pub(super) struct SectionId(usize);
 /// of section ids with the matched section and name, and is used for precedence
 /// management.
 #[derive(PartialEq, Eq, Clone, Debug)]
-enum LookupTreeNode<'a> {
+pub(super) enum LookupTreeNode<'a> {
     Terminal(Vec<SectionId>),
     NonTerminal(HashMap<Cow<'a, str>, Vec<SectionId>>),
 }
 
 /// High level `git-config` reader and writer.
 ///
+/// This is the full-featured implementation that can deserialize, serialize,
+/// and edit `git-config` files without loss of whitespace or comments. As a
+/// result, it's lot more complex than it's read-only variant,
+/// [`ResolvedGitConfig`] that exposes a [`HashMap`]-like interface. Users that
+/// only need to read `git-config` files should use that instead.
+///
 /// Internally, this uses various acceleration data structures to improve
 /// performance of the typical usage behavior of many lookups and relatively
 /// fewer insertions.
@@ -78,6 +91,7 @@ enum LookupTreeNode<'a> {
 /// Consider the `multi` variants of the methods instead, if you want to work
 /// with all values instead.
 ///
+/// [`ResolvedGitConfig`]: crate::file::ResolvedGitConfig
 /// [`get_raw_value`]: Self::get_raw_value
 #[derive(PartialEq, Eq, Clone, Debug, Default)]
 pub struct GitConfig<'event> {
@@ -88,13 +102,13 @@ pub struct GitConfig<'event> {
     /// Section name and subsection name to section id lookup tree. This is
     /// effectively a n-tree (opposed to a binary tree) that can have a height
     /// of at most three (including an implicit root node).
-    section_lookup_tree: HashMap<SectionHeaderName<'event>, Vec<LookupTreeNode<'event>>>,
+    pub(super) section_lookup_tree: HashMap<SectionHeaderName<'event>, Vec<LookupTreeNode<'event>>>,
     /// SectionId to section mapping. The value of this HashMap contains actual
     /// events.
     ///
     /// This indirection with the SectionId as the key is critical to flexibly
     /// supporting `git-config` sections, as duplicated keys are permitted.
-    sections: HashMap<SectionId, SectionBody<'event>>,
+    pub(super) sections: HashMap<SectionId, SectionBody<'event>>,
     section_headers: HashMap<SectionId, ParsedSectionHeader<'event>>,
     /// Internal monotonically increasing counter for section ids.
     section_id_counter: usize,
@@ -167,7 +181,7 @@ impl<'event> GitConfig<'event> {
                     Cow::Owned(value.into_bytes()),
                 );
             } else {
-                return Err(GitConfigFromEnvError::InvalidKeyValue(key.to_string()));
+                return Err(GitConfigFromEnvError::InvalidKeyValue(i, key.to_string()));
             }
         }
 
@@ -528,14 +542,16 @@ impl<'event> GitConfig<'event> {
 
     /// Returns the number of entries in the config. This ignores any comments.
     /// For example, a config with multiple empty sections will return 0.
+    #[must_use]
     pub fn len(&self) -> usize {
         self.sections.values().fold(0, |acc, section| acc + section.len())
     }
 
     /// Returns if there are no entries in the config. This will return true
     /// if there are only empty sections or comments.
+    #[must_use]
     pub fn is_empty(&self) -> bool {
-        self.sections.values().all(|section| section.is_empty())
+        self.sections.values().all(SectionBody::is_empty)
     }
 }
 
@@ -1210,9 +1226,10 @@ impl Display for GitConfig<'_> {
 
 #[cfg(test)]
 mod mutable_value {
-    use super::GitConfig;
     use std::convert::TryFrom;
 
+    use super::GitConfig;
+
     fn init_config() -> GitConfig<'static> {
         GitConfig::try_from(
             r#"[core]
@@ -1347,9 +1364,10 @@ b
 
 #[cfg(test)]
 mod mutable_multi_value {
-    use super::GitConfig;
     use std::{borrow::Cow, convert::TryFrom};
 
+    use super::GitConfig;
+
     fn init_config() -> GitConfig<'static> {
         GitConfig::try_from(
             r#"[core]
@@ -1488,8 +1506,10 @@ a"#,
 #[cfg(test)]
 mod from_parser {
     use super::{Cow, Event, GitConfig, HashMap, LookupTreeNode, SectionBody, SectionId, TryFrom};
-    use crate::parser::SectionHeaderName;
-    use crate::test_util::{name_event, newline_event, section_header, value_event};
+    use crate::{
+        parser::SectionHeaderName,
+        test_util::{name_event, newline_event, section_header, value_event},
+    };
 
     #[test]
     fn parse_empty() {
@@ -1744,9 +1764,10 @@ mod get_raw_value {
 
 #[cfg(test)]
 mod get_value {
+    use std::error::Error;
+
     use super::{Cow, GitConfig, TryFrom};
     use crate::values::{Boolean, TrueVariant, Value};
-    use std::error::Error;
 
     #[test]
     fn single_section() -> Result<(), Box<dyn Error>> {
