@@ -2,16 +2,19 @@
 
 mod error;
 mod git_config;
+mod resolved;
 mod section;
 mod value;
 
 use std::ops::{Add, AddAssign};
 
-pub use self::git_config::*;
 pub use error::*;
+pub use resolved::*;
 pub use section::*;
 pub use value::*;
 
+pub use self::git_config::*;
+
 /// Newtype to represent an index into some range. This is to differentiate
 /// between raw usizes when multiple are present.
 #[derive(PartialEq, Eq, Hash, PartialOrd, Ord, Debug, Clone, Copy)]
