@@ -9,19 +9,21 @@
 //!
 //! [`GitConfig`]: crate::file::GitConfig
 
-use nom::branch::alt;
-use nom::bytes::complete::{escaped, tag, take_till, take_while};
-use nom::character::complete::{char, none_of, one_of};
-use nom::character::{is_newline, is_space};
-use nom::combinator::{map, opt};
-use nom::error::{Error as NomError, ErrorKind};
-use nom::multi::{many0, many1};
-use nom::sequence::delimited;
-use nom::IResult;
-use std::iter::FusedIterator;
-use std::{borrow::Cow, hash::Hash};
-use std::{convert::TryFrom, path::Path};
-use std::{fmt::Display, io::Read};
+use std::{borrow::Cow, convert::TryFrom, fmt::Display, hash::Hash, io::Read, iter::FusedIterator, path::Path};
+
+use nom::{
+    branch::alt,
+    bytes::complete::{escaped, tag, take_till, take_while},
+    character::{
+        complete::{char, none_of, one_of},
+        is_newline, is_space,
+    },
+    combinator::{map, opt},
+    error::{Error as NomError, ErrorKind},
+    multi::{many0, many1},
+    sequence::delimited,
+    IResult,
+};
 
 /// Syntactic events that occurs in the config. Despite all these variants
 /// holding a [`Cow`] instead over a simple reference, the parser will only emit
@@ -541,6 +543,21 @@ pub enum ParserOrIoError<'a> {
 }
 
 impl ParserOrIoError<'_> {
+    /// Coerces into an owned instance. This differs from the standard [`clone`]
+    /// implementation as calling clone will _not_ copy the borrowed variant,
+    /// while this method will. In other words:
+    ///
+    /// | Borrow type | `.clone()` | `to_owned()` |
+    /// | ----------- | ---------- | ------------ |
+    /// | Borrowed    | Borrowed   | Owned        |
+    /// | Owned       | Owned      | Owned        |
+    ///
+    /// This can be most effectively seen by the differing lifetimes between the
+    /// two. This method guarantees a `'static` lifetime, while `clone` does
+    /// not.
+    ///
+    /// [`clone`]: std::clone::Clone::clone
+    #[must_use]
     pub fn into_owned(self) -> ParserOrIoError<'static> {
         match self {
             ParserOrIoError::Parser(error) => ParserOrIoError::Parser(error.to_owned()),
